summaryrefslogtreecommitdiffstats
path: root/knetworkconf/knetworkconf/knetworkconf.h
diff options
context:
space:
mode:
Diffstat (limited to 'knetworkconf/knetworkconf/knetworkconf.h')
-rw-r--r--knetworkconf/knetworkconf/knetworkconf.h88
1 files changed, 44 insertions, 44 deletions
diff --git a/knetworkconf/knetworkconf/knetworkconf.h b/knetworkconf/knetworkconf/knetworkconf.h
index 3416776..813b150 100644
--- a/knetworkconf/knetworkconf/knetworkconf.h
+++ b/knetworkconf/knetworkconf/knetworkconf.h
@@ -29,17 +29,17 @@
#include <sys/types.h>
#include <kapp.h>
-#include <qwidget.h>
-#include <qpixmap.h>
-#include <qprocess.h>
-#include <qptrlist.h>
-#include <qstringlist.h>
-#include <qstring.h>
-#include <qcheckbox.h>
-#include <qgroupbox.h>
-#include <qlabel.h>
-#include <qradiobutton.h>
-#include <qlayout.h>
+#include <tqwidget.h>
+#include <tqpixmap.h>
+#include <tqprocess.h>
+#include <tqptrlist.h>
+#include <tqstringlist.h>
+#include <tqstring.h>
+#include <tqcheckbox.h>
+#include <tqgroupbox.h>
+#include <tqlabel.h>
+#include <tqradiobutton.h>
+#include <tqlayout.h>
#include <kdialog.h>
#include <kinputdialog.h>
#include <kpopupmenu.h>
@@ -78,13 +78,13 @@ class KNetworkConf : public KNetworkConfDlg, virtual public KNetworkConfIface
Q_OBJECT
public:
/** construtor */
- KNetworkConf(QWidget* parent=0, const char *name=0);
+ KNetworkConf(TQWidget* parent=0, const char *name=0);
/** destructor */
~KNetworkConf();
/** Puts the application in read-only mode. This happens when the user runing the application isn't root. */
void setReadOnly(bool state);
- void setVersion(QString ver);
- QString getVersion();
+ void setVersion(TQString ver);
+ TQString getVersion();
/** Disables all buttons a line edit widgets when the user has read only access. */
void disableAll();
@@ -99,38 +99,38 @@ class KNetworkConf : public KNetworkConfDlg, virtual public KNetworkConfIface
private: // Private attributes
/** */
KNetworkConfigParser *config;
- KNetworkInterface * getDeviceInfo(QString device);
- QString getDeviceName(QString ipAddr);
- /** Creates a QStringList with the IP addresses contained in the QListBox of name servers. */
- QStringList getNamserversList(KListBox * serverList);
-/** Creates a QPtrList<KKownHostInfo> with the info contained in the KListView of name servers. */
- QPtrList<KKnownHostInfo> getKnownHostsList(KListView * hostsList);
- QString currentDevice;
+ KNetworkInterface * getDeviceInfo(TQString device);
+ TQString getDeviceName(TQString ipAddr);
+ /** Creates a TQStringList with the IP addresses contained in the TQListBox of name servers. */
+ TQStringList getNamserversList(KListBox * serverList);
+/** Creates a TQPtrList<KKownHostInfo> with the info contained in the KListView of name servers. */
+ TQPtrList<KKnownHostInfo> getKnownHostsList(KListView * hostsList);
+ TQString currentDevice;
KRoutingInfo *routingInfo;
KDNSInfo *dnsInfo;
bool reloaded;
- QString commandOutput;
- QProcess *procUpdateDevice;
- QProcess *procDeviceState;
- QStringList deviceNamesList;
+ TQString commandOutput;
+ TQProcess *procUpdateDevice;
+ TQProcess *procDeviceState;
+ TQStringList deviceNamesList;
bool devicesModified;
bool readOnly;
- QPtrList<KKnownHostInfo> knownHostsList;
- QPtrList<KNetworkInfo> profilesList;
+ TQPtrList<KKnownHostInfo> knownHostsList;
+ TQPtrList<KNetworkInfo> profilesList;
bool nameServersModified;
/** The program's version. */
- QString version;
+ TQString version;
bool modified;
bool devStateChanged;
/** */
KNetworkInfo * netInfo;
/** Has the errors throwed by GST when executed. */
- QString commandErrOutput;
+ TQString commandErrOutput;
/** Changes the state of device 'dev' to DEVICE_UP or DEVICE_DOWN.
Return true on success, false on failure. */
- void changeDeviceState(const QString &dev, int state);
- KNetworkInfo *getProfile(QPtrList<KNetworkInfo> profilesList, QString selectedProfile);
- void showSelectedProfile(QString profile);
+ void changeDeviceState(const TQString &dev, int state);
+ KNetworkInfo *getProfile(TQPtrList<KNetworkInfo> profilesList, TQString selectedProfile);
+ void showSelectedProfile(TQString profile);
KProfilesListViewToolTip *tooltip;
public slots:
@@ -157,22 +157,22 @@ class KNetworkConf : public KNetworkConfDlg, virtual public KNetworkConfIface
/** Shows the help browser. Hopefully some day it will be one :-). */
virtual void helpSlot();
virtual void enableApplyButtonSlot(bool);
- virtual void enableApplyButtonSlot(const QString &text);
+ virtual void enableApplyButtonSlot(const TQString &text);
/** Saves all the modified info of devices, routes,etc. */
virtual void moveDownServerSlot();
virtual void moveUpServerSlot();
virtual void removeServerSlot();
bool valuesChanged(KNetworkInterface *dev,
- QString bootProto,
- QString netmask,
- QString ipAddr,
- QString gateway,
+ TQString bootProto,
+ TQString netmask,
+ TQString ipAddr,
+ TQString gateway,
bool onBoot,
- QString desc,
- QString broadcast);
+ TQString desc,
+ TQString broadcast);
/** Returns a list of strings of all the configured devices. */
- QStringList getDeviceList();
- /** Sets the QPushButton::autoResize() in true for all buttons. */
+ TQStringList getDeviceList();
+ /** Sets the TQPushButton::autoResize() in true for all buttons. */
void makeButtonsResizeable();
/** Adds a new host to the KListView that has the known hosts. */
@@ -189,16 +189,16 @@ class KNetworkConf : public KNetworkConfDlg, virtual public KNetworkConfIface
void showMainWindow();
void verifyDeviceStateChanged();
/** Sees if a device is active or not in the ifconfig output. Not very nice, but it works. Inthe future, this has to be managed by gst. */
- bool isDeviceActive(const QString &device, const QString &ifconfigOutput);
+ bool isDeviceActive(const TQString &device, const TQString &ifconfigOutput);
/*Shows a context menu when right-clicking in the interface list*/
- void showInterfaceContextMenuSlot(KListView*, QListViewItem*, const QPoint&);
+ void showInterfaceContextMenuSlot(KListView*, TQListViewItem*, const TQPoint&);
/** Enable some signals in the GUI that need to be enabled *after* the loading of the network info is done.*/
void enableSignals ();
virtual void enableProfileSlot();
virtual void createProfileSlot();
- //virtual void updateProfileNameSlot(QListViewItem *item);
+ //virtual void updateProfileNameSlot(TQListViewItem *item);
virtual void removeProfileSlot();
virtual void updateProfileSlot();